@@ -551,6 +551,84 @@ class SubscribeCommand(Command):
         print(f"{timestamp} {source:04x} -> {destination:04x}: {message!r}")
 
 
+class AddSubscriptionCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
+    ELEMENT = 0
+    MODEL = ConfigClient
+    CMD = "add_subscription"
+    USAGE = """
+    Usage:
+        %(cmd)s -a=ADDRESS -m MODEL [options] <uuid>...
+        %(cmd)s -a=ADDRESS -m MODEL [options] -g <groups>...
+
+    Options:
+        -e --element=ELEMENT [default: 0]
+        -a --address=ADDRESS
+        -m --model=MODEL
+    """
+
+    async def __call__(self, application, arguments):
+        from bluetooth_mesh import models
+
+        model = self.get_model(application)
+        destinations = self.get_addresses(application, arguments)
+
+        element = int(arguments["--element"]) if arguments["--element"] is not None else 0
+        address = int(arguments["--address"], 16) if arguments["--address"] is not None else 0
+        if not destinations:
+            yield "invalid uuid!"
+        for dst in destinations:
+            element_address = dst + element
+
+            results = await model.add_subscription(
+                dst, 0, element_address, address, model=getattr(models, arguments["--model"])
+            )
+
+            node = application.network.get_node(address=dst)
+            if results is None:
+                yield f"{dst} | Subscription Status not received"
+            else:
+                yield f"{dst} | {node.name}:\n{results}"
+
+
+class BindAppKeyCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
+    ELEMENT = 0
+    MODEL = ConfigClient
+    CMD = "bind_appkey"
+    USAGE = """
+    Usage:
+        %(cmd)s -m MODEL [options] <uuid>...
+        %(cmd)s -m MODEL [options] -g <groups>...
+
+    Options:
+        -e --element=ELEMENT [default: 0]
+        -k --keyindex=KEY_INDEX [default: 0]
+        -m --model=MODEL
+    """
+
+    async def __call__(self, application, arguments):
+        from bluetooth_mesh import models
+
+        model = self.get_model(application)
+        destinations = self.get_addresses(application, arguments)
+        if not destinations:
+            yield "invalid uuid!"
+
+        element = int(arguments["--element"]) if arguments["--element"] is not None else 0
+        key_index = int(arguments["--keyindex"]) if arguments["--keyindex"] is not None else 0
+        for dst in destinations:
+            element_address = dst + element
+
+            results = await model.bind_app_key(
+                dst, 0, element_address, key_index, model=getattr(models, arguments["--model"])
+            )
+
+            node = application.network.get_node(address=dst)
+            if results is None:
+                yield f"{dst} | Bind AppKey Status not received"
+            else:
+                yield f"{dst} | {node.name}:\n{results}"
+
+
 class UnsubscribeCommand(Command):
     CMD = "unsubscribe"
     USAGE = """
@@ -1202,14 +1280,12 @@ class TimeGetCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
         results = await model.get_time(nodes=addresses, app_index=0)
 
         for address, pkt_time in results.items():
-            if pkt_time is None:
-                yield f"{address} | Time Status not received"
             node = application.network.get_node(address=address)
             group = application.network.get_node_group(node)
             if pkt_time is None:
-                yield f"{address} | Time Status not received"
+                yield f"{group} | {node.name}\nTime Status not received"
             elif pkt_time["date"] is None:
-                yield f"{address} | Time is not set!"
+                yield f"{group} | {node.name}\nTime is not set!"
             else:
                 yield "{} | {}:\n{} +- {} s".format(
                     group,
@@ -1223,9 +1299,9 @@ class TimeCurrentSetCommand(ModelCommandMixin, NodeSelectionCommandMixin, Comman
     USAGE = """
     Usage:
         %(cmd)s [options] <uuid>...
+        %(cmd)s [options] -g <groups>...
 
     Options:
-        -g --groups <group>
         -o --offset <seconds>
 
     """
@@ -1252,9 +1328,9 @@ class TimeCurrentSetCommand(ModelCommandMixin, NodeSelectionCommandMixin, Comman
             node = application.network.get_node(address=address)
             group = application.network.get_node_group(node)
             if pkt_time is None:
-                yield f"{address} | Time Status not received"
+                yield f"{group} | {node.name}\nTime Status not received"
             elif pkt_time["date"] is None:
-                yield f"{address} | Time is not set!"
+                yield f"{group} | {node.name}\nTime is not set!"
             else:
                 yield "{} | {}:\n{} +- {} s".format(
                     group,
@@ -1269,9 +1345,7 @@ class TimeRoleGetCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
     Usage:
         %(cmd)s [options] <uuid>...
         %(cmd)s [options] -g <groups>...
-
-    Options:
-        -g --groups
+        %(cmd)s [options] --subnets <subnets>...
 
     """
     CMD = "time_role_get"
@@ -1286,22 +1360,23 @@ class TimeRoleGetCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
 
         for address, pkt_time in results.items():
             if pkt_time is None:
-                yield f"{address} | Time Role Status not received"
-            node = application.network.get_node(address=address)
-            group = application.network.get_node_group(node)
+                yield f"{group} | {node.name}:\nTime Role Status not received"
+            else:
+                node = application.network.get_node(address=address)
+                group = application.network.get_node_group(node)
 
-            yield f"{group} | {node.name}:\nTime Role: " + str(
-                TimeRole(pkt_time["time_role"])
-            )
+                yield f"{group} | {node.name}:\nTime Role: " + str(
+                    TimeRole(pkt_time["time_role"])
+                )
 
 
 class TimeRoleSetCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
     USAGE = """
     Usage:
         %(cmd)s [options] <uuid>...
+        %(cmd)s [options] -g <groups>...
 
     Options:
-        -g --groups <groups>
         -r --role <role>
 
     """
@@ -1315,18 +1390,19 @@ class TimeRoleSetCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
         time_role = (
             TimeRole(int(arguments.get("--role")))
             if arguments.get("--role") is not None
-            else TimeRole.TIME_ROLE_TIME_CLIENT
+            else TimeRole.TIME_CLIENT
         )
 
         results = await model.set_time_role(addresses, 0, time_role)
         for address, pkt_time in results.items():
-            if pkt_time is None:
-                yield f"{address} | Time Role Status not received"
             node = application.network.get_node(address=address)
             group = application.network.get_node_group(node)
-            yield f"{group} | {node.name}:\nTime Role: " + str(
-                TimeRole(pkt_time["time_role"])
-            )
+            if pkt_time is None:
+                yield f"{group} | {node.name}:\nTime Role Status not received"
+            else:
+                yield f"{group} | {node.name}:\nTime Role: " + str(
+                    TimeRole(pkt_time["time_role"])
+                )
 
 
 class HelpCommand(Command):
@@ -1390,6 +1466,8 @@ class MeshCommandLine(*application_mixins, Application):
         AclCommand,
         PublicationCommand,
         SubscribeCommand,
+        AddSubscriptionCommand,
+        BindAppKeyCommand,
         UnsubscribeCommand,
         LightExtendedControllerCommand,
         LightRangeCommand,
@@ -1436,7 +1514,6 @@ class MeshCommandLine(*application_mixins, Application):
 
             with open(f"{self.config_dir}/{self.uuid}.key", "wb") as dev_key:
                 dev_key.write(key.bytes)
-
             return key
 
     async def get_network(
