@@ -114,7 +114,7 @@ ModelSubscriptionList = NamedTuple(
 )
 
 ModelPublicationStatus = NamedTuple(
-    "ModelSubscriptionStatus",
+    "ModelPublicationStatus",
     [
         ("element_address", int),
         ("publication_address", int),
@@ -2340,8 +2340,36 @@ class LightExtendedControllerSetupClient(Model):
         )
 
 
-class TimeClient(Model):
+class TimeServer(Model):
     MODEL_ID = (None, 0x1200)
+    OPCODES = {
+        TimeOpcode.TIME_GET,
+        TimeOpcode.TIME_STATUS,
+        TimeOpcode.TIME_ZONE_GET,
+        TimeOpcode.TIME_ZONE_STATUS,
+        TimeOpcode.TAI_UTC_DELTA_GET,
+        TimeOpcode.TAI_UTC_DELTA_STATUS,
+    }
+    PUBLISH = True
+    SUBSCRIBE = True
+
+
+class TimeSetupServer(Model):
+    MODEL_ID = (None, 0x1201)
+    OPCODES = {
+        TimeOpcode.TIME_SET,
+        TimeOpcode.TIME_ZONE_SET,
+        TimeOpcode.TAI_UTC_DELTA_SET,
+        TimeOpcode.TIME_ROLE_SET,
+        TimeOpcode.TIME_ROLE_GET,
+        TimeOpcode.TIME_ROLE_STATUS
+    }
+    PUBLISH = False
+    SUBSCRIBE = False
+
+
+class TimeClient(Model):
+    MODEL_ID = (None, 0x1202)
     OPCODES = {
         TimeOpcode.TIME_GET,
         TimeOpcode.TIME_SET,
